/* apps/verify.c */
/* Copyright (C) 1995 Eric Young (eay@mincom.oz.au)
 * All rights reserved.
 * 
 * This file is part of an SSL implementation written
 * by Eric Young (eay@mincom.oz.au).
 * The implementation was written so as to conform with Netscapes SSL
 * specification.  This library and applications are
 * FREE FOR COMMERCIAL AND NON-COMMERCIAL USE
 * as long as the following conditions are aheared to.
 * 
 * Copyright remains Eric Young's, and as such any Copyright notices in
 * the code are not to be removed.  If this code is used in a product,
 * Eric Young should be given attribution as the author of the parts used.
 * This can be in the form of a textual message at program startup or
 * in documentation (online or textual) provided with the package.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *    This product includes software developed by Eric Young (eay@mincom.oz.au)
 * 
 * THIS SOFTWARE IS PROVIDED BY ERIC YOUNG ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * 
 * The licence and distribution terms for any publically available version or
 * derivative of this code cannot be changed.  i.e. this code cannot simply be
 * copied and put under another distribution licence
 * [including the GNU Public Licence.]
 */

#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include "apps.h"
#include "err.h"
#include "der.h"
#include "x509.h"
#include "pem.h"

#define PROG	verify_main

#ifdef PROTO
static int cb(int ok, X509 *xs, X509 *xi, int depth, int error);
static int check(char *file);
#else
static int cb();
static int check();
#endif

int MAIN(argc, argv)
int argc;
char **argv;
	{
	int i;
	char *CApath=NULL,*CAfile=NULL;

	ERR_load_crypto_strings();

	if (!X509_set_default_verify_paths())
		{ EXIT(1); }

	argc--;
	argv++;
	for (;;)
		{
		if (argc >= 1)
			{
			if (strcmp(*argv,"-CApath") == 0)
				{
				if (argc-- < 1) goto bad;
				CApath= *(++argv);
				}
			else if (strcmp(*argv,"-CAfile") == 0)
				{
				if (argc-- < 1) goto bad;
				CAfile= *(++argv);
				}
			else if (strcmp(*argv,"-help") == 0)
				goto bad;
			else
				break;
			argc--;
			argv++;
			}
		else
			break;
		}

	if ((!X509_load_verify_locations(CAfile,CApath)) ||
		(!X509_set_default_verify_paths()))
		{
		fprintf(stderr,"X509_load_verify_locations\n");
		ERR_print_errors(stderr);
		EXIT(1);
		}

	if (argc < 1) check(NULL);
	else
		for (i=0; i<argc; i++)
			check(argv[i]);
	EXIT(0);
bad:
	fprintf(stderr,"usage: verify [-CApath path] [-CAfile file] cert1 cert2 ...\n");
	EXIT(1);
	}

static int check(file)
char *file;
	{
	X509 *x;
	FILE *in;
	int i;

	if (file != NULL)
		{
		in=fopen(file,"r");
		if (in == NULL)
			{
			perror(file);
			return(0);
			}
		}
	else
		in=stdin;

	x=(X509 *)X509_new();
	i=PEM_read_X509(in,x);
	if (!i)
		{
		fprintf(stdout,"%s: unable to load certificate file\n",
			file);
		ERR_print_errors(stderr);
		X509_free(x);
		return(1);
		}
	if (in != stdin) fclose(in);
	fprintf(stdout,"%s: ",file);
	i=X509_verify(x,cb);
	if (i) fprintf(stdout,"OK\n");
	else	ERR_print_errors(stderr);
	X509_free(x);
	return(1);
	}

static int cb(ok, xs, xi, depth, error)
int ok;
X509 *xs;
X509 *xi;
int depth;
int error;
	{
	if (!ok)
		{
		char *s;
		/* since we are just checking the certificates, it is
		 * ok if they are self signed. */
		if (error == VERIFY_ERR_DEPTH_ZERO_SELF_SIGNED_CERT)
			ok=1;
		else
			{
			s=X509_oneline_X509_NAME(X509_get_subject_name(xs));
			printf("%s\n",s);
			free(s);
			printf("error %d at %d:%s\n",error,depth,
				X509_verify_error_string(error));
			}
		}
	ERR_clear_error();
#ifdef LINT
	xi=xs; xs=xi;
#endif
	return(ok);
	}

